@@ -1,5 +1,5 @@
 bumpchart<-function (y,top.labels=colnames(y),labels=rownames(y),rank=TRUE,
- mar=c(2,8,5,8),pch=19,...) {
+ mar=c(2,8,5,8),pch=19,col=par("fg"),lty=1,lwd=1,...) {
 
  if(missing(y)) 
   stop("Usage: spread.labels(y,labels,...)")
@@ -8,10 +8,14 @@ bumpchart<-function (y,top.labels=colnames(y),labels=rownames(y),rank=TRUE,
  oldmar<-par("mar")
  par(mar=mar)
  if(rank) y<-apply(y,2,rank)
+ # to get things the right way round, reverse the order of everything
  labels<-rev(labels)
+ pch=rev(pch)
+ col=rev(col)
+ lty=rev(lty)
+ lwd=rev(lwd)
  y<-apply(y,2,rev)
- ny<-length(y)
- matplot(t(y),ylab="",type="b",pch=pch,axes=FALSE,...)
+ matplot(t(y),ylab="",type="b",pch=pch,col=col,lty=lty,lwd=lwd,axes=FALSE,...)
  par(xpd=TRUE)
  xylim<-par("usr")
  minspacing<-strheight("M")*1.5
